from .currency import Currency
from .locale import Locale
from .modifier_operator import ModifierOperator
from .parameter_type import ParameterType
from .pricing_type import PricingType
from .product_types import ProductTypes
from .sync_task_type import SyncTaskType
from .sync_task_status import SyncTaskStatus
from .sync_task_priority import SyncTaskPriority

__all__ = (
    "Currency",
    "Locale",
    "ModifierOperator",
    "ParameterType",
    "PricingType",
    "ProductTypes",
    "SyncTaskType",
    "SyncTaskStatus",
    "SyncTaskPriority",
)



from datetime import datetime
from typing import Annotated

from litestar.params import Parameter
from msgspec import Struct

from stofory_sdk.catalog.models.enums import ProductTypes

from .product_platform_schema import ProductPlatformResponse


class ProductCreateRequest(Struct, forbid_unknown_fields=True):
    name: Annotated[
        str,
        Parameter(
            title="Name",
            description="The name of the product."
        )
    ]
    description: Annotated[
        str,
        Parameter(
            title="Description",
            description="The description of the product."
        )
    ]
    product_type: Annotated[
        ProductTypes,
        Parameter(
            title="Product Type",
            description="The type of the product.",
            examples=[
                ProductTypes.STEAM_GIFT,
                ProductTypes.STEAM_TOPUP
            ]
        )
    ]
    slug: Annotated[
        str,
        Parameter(
            title="Slug",
            description="The slug of the product."
        )
    ]


class ProductUpdateRequest(Struct, forbid_unknown_fields=True):
    name: Annotated[
        str,
        Parameter(
            title="Name",
            description="The name of the product."
        )
    ]
    description: Annotated[
        str,
        Parameter(
            title="Description",
            description="The description of the product."
        )
    ]
    product_type: Annotated[
        ProductTypes,
        Parameter(
            title="Product Type",
            description="The type of the product.",
            examples=[
                ProductTypes.STEAM_GIFT,
                ProductTypes.STEAM_TOPUP
            ]
        )
    ]
    slug: Annotated[
        str,
        Parameter(
            title="Slug",
            description="The slug of the product."
        )
    ]


class ProductResponse(Struct):
    id: int
    name: str
    description: str
    product_type: ProductTypes
    status: bool
    slug: str
    created_at: datetime
    updated_at: datetime

    product_platforms: list[ProductPlatformResponse]


class PlatformShortResponse(Struct):
    id: int
    name: str


class ProductPlatformShortWithPlatformResponse(Struct):
    id: int
    platform: PlatformShortResponse


class ProductShortenedResponse(ProductResponse):
    product_platforms: list[ProductPlatformShortWithPlatformResponse]



from datetime import datetime
from typing import Annotated, Any

from sqlalchemy_utils.types.ltree import Ltree
from litestar.params import Parameter
from msgspec import Struct


class CategoryCreateRequest(Struct, forbid_unknown_fields=True):
    platform_id: Annotated[
        int,
        Parameter(
            title="Platform ID",
            description="The ID of the platform."
        )
    ]
    name: Annotated[
        str,
        Parameter(
            title="Name",
            description="The name of the category."
        )
    ]
    slug: Annotated[
        str,
        Parameter(
            title="Slug",
            description="The slug of the category."
        )
    ]
    path: Annotated[
        Any,
        Parameter(
            title="Path",
            description="The path of the category."
        )
    ]
    parent_id: Annotated[
        int | None,
        Parameter(
            title="Parent ID",
            description="The ID of the parent category."
        )
    ] = None


class CategoryUpdateRequest(Struct, forbid_unknown_fields=True):
    platform_id: Annotated[
        int,
        Parameter(
            title="Platform ID",
            description="The ID of the platform."
        )
    ]
    parent_id: Annotated[
        int | None,
        Parameter(
            title="Parent ID",
            description="The ID of the parent category."
        )
    ]
    path: Annotated[
        Any,
        Parameter(
            title="Path",
            description="The path of the category."
        )
    ]
    name: Annotated[
        str,
        Parameter(
            title="Name",
            description="The name of the category."
        )
    ]
    slug: Annotated[
        str,
        Parameter(
            title="Slug",
            description="The slug of the category."
        )
    ]


class CategoryResponse(Struct):
    id: int
    platform_id: int
    parent_id: int | None
    path: Any
    name: str
    slug: str
    created_at: datetime
    updated_at: datetime
